Crate librpm

Crate librpm 

Rust binding for librpm: the RPM Package Manager library

This crate contains idiomatic Rust bindings which aim to expose a safe API to librpm. The low-level unsafe bindings are located in the librpm-sys crate, which is automatically generated by bindgen.

Call init (or init_with for custom configuration) before using the library, then obtain a Db handle via Db::open to query the RPM database.

Re-exports

pub use self::db::Db;
pub use self::db::Index;
pub use self::dep::DepFlags;
pub use self::dep::Dependencies;
pub use self::dep::Dependency;
pub use self::error::Error;
pub use self::files::FileAttrs;
pub use self::files::FileEntry;
pub use self::files::Files;
pub use self::macro_context::MacroContext;
pub use self::package::Package;
pub use self::version::Version;

Modules

db
RPM database access RPM database access
dep
Dependency information for RPM packages Dependency information for RPM packages
error
Error types (defined first due to macros) librpm error types
files
File information for RPM packages File information for RPM packages
macro_context
Macros are RPM’s configuration system RPM macros are configuration parameters that have largely replaced the previous rpmrc system.
package
RPM packages RPM package type: represents .rpm files or entries in the RPM database
sign
RPM package signing (requires the sign feature) RPM package signing and signature removal
version
RPM version parsing and comparison RPM version parsing and comparison

Enums

RpmErrorKind
Errors returned by librpm operations such as reading package files
Tag
Identifiers for data in RPM headers (rpmTag_e in librpm)
TagData
Data found in RPM headers, associated with a particular Tag value.

Functions

init
Initialize librpm with default configuration.
init_with
Initialize librpm with custom configuration.